# Nifki

© Alistair Turnbull and Tom Lynn  

Nifki is a DIY games system. You don’t need to install any software, just visit the [Nifki site](https://nifki.net), browse the games, maybe read the tutorial, and then copy and modify or invent your own game!
